==> opennebula_5.10.1.orig.tar.gz: opennebula-5.10.1/src/oca/go/src/goca/schemas/cluster/template.go <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2019, OpenNebula Project, OpenNebula Systems                */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/*--------------------------------------------------------------------------- */

package cluster

import (
	dyn "github.com/OpenNebula/one/src/oca/go/src/goca/dynamic"
	"github.com/OpenNebula/one/src/oca/go/src/goca/schemas/cluster/keys"
)

// Template is a cluster template
type Template struct {
	dyn.Template
}

// Get returns the string value for an cluster template keys
func (n *Template) Get(key keys.Template) (string, error) {
	return n.GetStr(string(key))
}

// GetI returns the integer value for a cluster template key
func (n *Template) GetI(key keys.Template) (int, error) {
	return n.GetInt(string(key))
}

// Add adds an cluster template key, value pair
func (n *Template) Add(key keys.Template, value string) {
	n.AddPair(string(key), value)
}

==> opennebula-7.1.80.tar.gz: opennebula-7.1.80/src/oca/go/src/goca/schemas/cluster/template.go <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2025, OpenNebula Project, OpenNebula Systems                */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/*--------------------------------------------------------------------------- */

package cluster

import (
	dyn "github.com/OpenNebula/one/src/oca/go/src/goca/dynamic"
	"github.com/OpenNebula/one/src/oca/go/src/goca/schemas/cluster/keys"
)

// Template is a cluster template
type Template struct {
	dyn.Template
}

// Get returns the string value for an cluster template keys
func (n *Template) Get(key keys.Template) (string, error) {
	return n.GetStr(string(key))
}

// GetI returns the integer value for a cluster template key
func (n *Template) GetI(key keys.Template) (int, error) {
	return n.GetInt(string(key))
}

// Add adds an cluster template key, value pair
func (n *Template) Add(key keys.Template, value interface{}) {
	n.AddPair(string(key), value)
}
